DHCPKit Technicolor
===================

This package contains contains extensions to DHCPKit specific to Technicolor devices.

Distribution status
-------------------

.. image:: https://img.shields.io/pypi/v/dhcpkit_technicolor.svg
  :target: https://pypi.python.org/pypi/dhcpkit_technicolor

.. image:: https://img.shields.io/pypi/status/dhcpkit_technicolor.svg
  :target: https://pypi.python.org/pypi/dhcpkit_technicolor

.. image:: https://img.shields.io/pypi/l/dhcpkit_technicolor.svg
  :target: https://pypi.python.org/pypi/dhcpkit_technicolor

.. image:: https://img.shields.io/pypi/pyversions/dhcpkit_technicolor.svg
  :target: https://pypi.python.org/pypi/dhcpkit_technicolor

.. image:: https://img.shields.io/pypi/dw/dhcpkit_technicolor.svg
  :target: https://pypi.python.org/pypi/dhcpkit_technicolor
